=== modified file 'lib/canonical/database/sqlbase.py'
--- lib/canonical/database/sqlbase.py	2011-09-20 11:58:11 +0000
+++ lib/canonical/database/sqlbase.py	2011-09-24 02:32:44 +0000
@@ -59,6 +59,7 @@
 
 from canonical.config import dbconfig
 from canonical.database.interfaces import ISQLBase
+from lp.services.mail.sendmail import set_immediate_mail_delivery
 from lp.services.propertycache import clear_property_cache
 
 # Default we want for scripts, and the PostgreSQL default. Note psycopg1 will
@@ -289,6 +290,7 @@
         cls._isolation = isolation
         cls._reset_stores()
         cls._installed = cls
+        set_immediate_mail_delivery(True)
 
     @staticmethod
     def _reset_stores():
@@ -329,6 +331,7 @@
         dbconfig.override(dbuser=None, isolation_level=None)
         cls._reset_stores()
         cls._installed = None
+        set_immediate_mail_delivery(False)
 
 
 def clear_current_connection_cache():

=== modified file 'lib/lp/services/mail/sendmail.py'
--- lib/lp/services/mail/sendmail.py	2011-09-18 07:22:34 +0000
+++ lib/lp/services/mail/sendmail.py	2011-09-24 02:32:44 +0000
@@ -51,7 +51,6 @@
 from zope.sendmail.interfaces import IMailDelivery
 
 from canonical.config import config
-from canonical.database.sqlbase import ZopelessTransactionManager
 from lp.app import versioninfo
 from lp.services.encoding import is_ascii_only
 from lp.services.mail.stub import TestMailer
@@ -64,6 +63,7 @@
 Charset.add_charset('utf-8', Charset.SHORTEST, Charset.QP, 'utf-8')
 Charset.add_alias('utf8', 'utf-8')
 
+
 def do_paranoid_email_content_validation(from_addr, to_addrs, subject, body):
     """Validate various bits of the email.
 
@@ -161,6 +161,20 @@
     return format_address(person.displayname, email_address)
 
 
+_immediate_mail_delivery = False
+
+
+def set_immediate_mail_delivery(enabled):
+    """Enable or disable immediate mail delivery.
+
+    Mail is by default queued until the transaction is committed. But if
+    a script requires that mail violate transactions, immediate mail
+    delivery can be enabled.
+    """
+    global _immediate_mail_delivery
+    _immediate_mail_delivery = enabled
+
+
 def simple_sendmail(from_addr, to_addrs, subject, body, headers=None,
                     bulk=True):
     """Send an email from from_addr to to_addrs with the subject and body
@@ -422,7 +436,7 @@
 
     raw_message = message.as_string()
     message_detail = message['Subject']
-    if ZopelessTransactionManager._installed is not None:
+    if _immediate_mail_delivery:
         # Zopeless email sending is not unit tested, and won't be.
         # The zopeless specific stuff is pretty simple though so this
         # should be fine.

